==> ukelli-ui-3.0.0.tgz: package/core/menu/menus.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import React from 'react';
import Menu from './menu';
var menuDividGroup = ['-', 'hr'];
var Menus = function (props) {
    var data = props.data, children = props.children;
    return (React.createElement("span", { className: "uke-menus" }, data ? data.map(function (item, idx) {
        if (!item)
            return null;
        if (typeof item === 'string' && menuDividGroup.indexOf(item) !== -1) {
            return (React.createElement("hr", { key: idx }));
        }
        var _a = item, action = _a.action, id = _a.id, other = __rest(_a, ["action", "id"]);
        return (React.createElement(Menu, __assign({ key: id || idx, onClick: action }, other)));
    }) : children));
};
export default Menus;

==> ukelli-ui-3.3.1.tgz: package/core/menu/menus.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import Menu from './menu';
var menuDividGroup = ['-', 'hr'];
var Menus = function (props) {
    var data = props.data, children = props.children;
    return (React.createElement("span", { className: "__menus" }, data ? data.map(function (item, idx) {
        if (!item)
            return null;
        if (typeof item === 'string' && menuDividGroup.indexOf(item) !== -1) {
            return (React.createElement("hr", { key: idx }));
        }
        var _a = item, action = _a.action, id = _a.id, other = __rest(_a, ["action", "id"]);
        return (React.createElement(Menu, __assign({ key: id || idx, onClick: action }, other)));
    }) : children));
};
export default Menus;
